PyXMake Developer Guide: PyXMake.Build Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Namespaces
PyXMake.Build Namespace Reference

Module containing all relevant modules and scripts associated with the building process. More...

## Namespaces
namespace | __install__
| Fetch 3rd party dependencies for PyXMake from DLR's resource server.
namespace | Make
| Create a make object to define the building environment.

## Detailed Description

Module containing all relevant modules and scripts associated with the building process.

    Contains classes to define a make object controlling the building process.

    @note: PyXMake module
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  20.03.2018

Notes/Changes
  - Added documentation // mg 29.03.2018